summaryrefslogtreecommitdiffstats
path: root/kmail/kmfoldercachedimap.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:50 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:50 -0600
commit9cc13dcbb01a96c9e60a07ca63c61d24b374f50d (patch)
treeab537a329b9613e11dce8195761f93ffe82aed24 /kmail/kmfoldercachedimap.h
parent3ca10fd9a2dc631429d3b5d5c5e42a7d211d5a12 (diff)
downloadtdepim-9cc13dcbb01a96c9e60a07ca63c61d24b374f50d.tar.gz
tdepim-9cc13dcbb01a96c9e60a07ca63c61d24b374f50d.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 3ca10fd9a2dc631429d3b5d5c5e42a7d211d5a12.
Diffstat (limited to 'kmail/kmfoldercachedimap.h')
-rw-r--r--kmail/kmfoldercachedimap.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kmail/kmfoldercachedimap.h b/kmail/kmfoldercachedimap.h
index bd084f00..dfef783a 100644
--- a/kmail/kmfoldercachedimap.h
+++ b/kmail/kmfoldercachedimap.h
@@ -285,8 +285,8 @@ public:
void setACLList( const ACLList& arr );
// Reimplemented so the mStatusChangedLocally bool can be set
- virtual void seStatus( int id, KMMsgStatus status, bool toggle );
- virtual void seStatus( TQValueList<int>& ids, KMMsgStatus status, bool toggle );
+ virtual void setqStatus( int id, KMMsgtqStatus status, bool toggle );
+ virtual void setqStatus( TQValueList<int>& ids, KMMsgtqStatus status, bool toggle );
TQString annotationFolderType() const { return mAnnotationFolderType; }
@@ -405,7 +405,7 @@ protected:
virtual void timerEvent( TQTimerEvent* );
/* update progress status */
- void newState( int progress, const TQString& syncStatus );
+ void newState( int progress, const TQString& synctqStatus );
/** See if there is a better parent then this folder */
KMFolderCachedImap* findParent( const TQString& path, const TQString& name );
@@ -590,7 +590,7 @@ private:
bool mSharedSeenFlagsChanged;
/**
* UIDs added by seStatus. Indicates that the client has changed
* the status of those mails. The mail flags for changed mails will be
* uploaded to the server, overwriting the server's notion of the status
* of the mails in this folder.
@@ -590,7 +590,7 @@ private:
bool mSharedSeenFlagsChanged;
/**
- * UIDs added by seStatus. Indicates that the client has changed
+ * UIDs added by setqStatus. Indicates that the client has changed
* the status of those mails. The mail flags for changed mails will be
* uploaded to the server, overwriting the server's notion of the status